<?php
/**
 * Customizer functionality
 *
 * @package Personal_Trainer
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since Personal Trainer 0.1
 *
 * @see personaltrainer_header_style()
 */
function personaltrainer_custom_header_and_background() {
	/**
	 * Filter the arguments used when adding 'custom-background' support in Personal Trainer.
	 *
	 * @since Personal Trainer 0.1
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'personaltrainer_custom_background_args', array(
		'default-color' => '#000000',
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Personal Trainer.
	 *
	 * @since Personal Trainer 0.1
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'personaltrainer_custom_header_args', array(
		'default-image'      	 => get_parent_theme_file_uri( '/assets/images/header.jpg' ),
		'default-text-color'     => '#666666',
		'width'                  => 1920,
		'height'                 => 1080,
		'flex-height'            => true,
		'flex-width'            => true,
		'wp-head-callback'       => 'personaltrainer_header_style',
		'video'                  => true,
	) ) );

	$default_headers_args = array(
		'main' => array(
			'thumbnail_url' => get_stylesheet_directory_uri() . '/assets/images/header-thumb.jpg',
			'url'           => get_stylesheet_directory_uri() . '/assets/images/header.jpg',
		),
	);

	register_default_headers( $default_headers_args );
}
add_action( 'after_setup_theme', 'personaltrainer_custom_header_and_background' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Personal Trainer 1.2
 * @see personaltrainer_customize_register()
 *
 * @return void
 */
function personaltrainer_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Personal Trainer 1.2
 * @see personaltrainer_customize_register()
 *
 * @return void
 */
function personaltrainer_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
